// components/ClientLayout.tsx - Client Component for client-side hooks and logic
"use client"; // Mark this as a client component

import { useEffect } from "react";
import Script from "next/script";
import { usePathname } from "next/navigation";
import MobileNavBar from "@/app/components/MobileNavBar"; // Import MobileNavBar for mobile view

export default function ClientLayout({ children }: { children: React.ReactNode }) {
  const pathname = usePathname(); // Use usePathname from next/navigation

  useEffect(() => {
    const handleRouteChange = (url: string) => {
      window.gtag('config', 'G-3E08CZ92PE', {
        page_path: url,
      });
    };

    handleRouteChange(pathname); // Track page path changes
  }, [pathname]);

  return (
    <>
      {/* Google Analytics Script */}
      <Script
        src="https://www.googletagmanager.com/gtag/js?id=G-3E08CZ92PE"
        strategy="afterInteractive"
      />
      <Script
        id="google-analytics"
        strategy="afterInteractive"
        dangerouslySetInnerHTML={{
          __html: `
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());
            gtag('config', 'G-3E08CZ92PE');
          `,
        }}
      />

      {/* Mobile Navigation */}
      <div className="md:hidden">
        <MobileNavBar />
      </div>

      {children} {/* Render the children inside the client component */}
    </>
  );
}
